# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from decimal import Decimal
import django_google_adwords.models
import djmoney.models.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('account_id', models.BigIntegerField(unique=True)),
                ('status', models.CharField(default=b'active', max_length=32, choices=[(b'active', b'Active'), (b'sync', b'Sync'), (b'inactive', b'Inactive')])),
                ('account', models.CharField(help_text=b'Account descriptive name', max_length=255, null=True, blank=True)),
                ('currency', models.CharField(help_text=b'Account currency code', max_length=255, null=True, blank=True)),
                ('account_last_synced', models.DateField(null=True, blank=True)),
                ('campaign_last_synced', models.DateField(null=True, blank=True)),
                ('ad_group_last_synced', models.DateField(null=True, blank=True)),
                ('ad_last_synced', models.DateField(null=True, blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Ad',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ad_id', models.BigIntegerField(help_text=b'Googles Ad ID')),
                ('ad_state', models.CharField(blank=True, max_length=20, null=True, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('ad_type', models.CharField(blank=True, max_length=20, null=True, choices=[(b'Other', b'Other'), (b'Image ad', b'Image Ad'), (b'Mobile ad', b'Mobile Ad'), (b'Product listing ad', b'Product Listing Ad'), (b'Display ad', b'Display Ad'), (b'Text ad', b'Text Ad'), (b'Third party ad', b'Third Party Ad'), (b'Dynamic search ad', b'Dynamic Search Ad')])),
                ('ad_approval_status', models.CharField(blank=True, max_length=20, null=True, choices=[(b'approved', b'Approved'), (b'approved (non family)', b'Approved (Non Family)'), (b'approved (adult)', b'Approved (Adult)'), (b'pending review', b'Pending Review'), (b'disapproved', b'Disapproved')])),
                ('destination_url', models.TextField(help_text=b'Destination URL', null=True, blank=True)),
                ('display_url', models.TextField(help_text=b'Display URL', null=True, blank=True)),
                ('ad', models.TextField(help_text=b'Ad/Headline', null=True, blank=True)),
                ('description_line_1', models.TextField(help_text=b'Description line 1', null=True, blank=True)),
                ('description_line_2', models.TextField(help_text=b'Description line 2', null=True, blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='AdGroup',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('ad_group_id', models.BigIntegerField(unique=True)),
                ('ad_group', models.CharField(help_text=b'Ad group name', max_length=255, null=True, blank=True)),
                ('ad_group_state', models.CharField(blank=True, max_length=20, null=True, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Alert',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('type', models.CharField(max_length=100, choices=[(b'ACCOUNT_ON_TARGET', b'Account On Target'), (b'DECLINED_PAYMENT', b'Declined Payment'), (b'CREDIT_CARD_EXPIRING', b'Credit Card Expiring'), (b'ACCOUNT_BUDGET_ENDING', b'Account Budget Ending'), (b'CAMPAIGN_ENDING', b'Campaign Ending'), (b'PAYMENT_NOT_ENTERED', b'Payment Not Entered'), (b'MISSING_BANK_REFERENCE_NUMBER', b'Missing Bank Reference Number'), (b'CAMPAIGN_ENDED', b'Campaign Ended'), (b'ACCOUNT_BUDGET_BURN_RATE', b'Account Budget Burn Rate'), (b'USER_INVITE_PENDING', b'User Invite Pending'), (b'USER_INVITE_ACCEPTED', b'User Invite Accepted'), (b'MANAGER_LINK_PENDING', b'Manager Link Pending'), (b'ZERO_DAILY_SPENDING_LIMIT', b'Zero Daily Spending Limit'), (b'TV_ACCOUNT_ON_TARGET', b'TV Account On Target'), (b'TV_ACCOUNT_BUDGET_ENDING', b'TV Account Budget Ending'), (b'TV_ZERO_DAILY_SPENDING_LIMIT', b'TV Zero Daily Spending Limit'), (b'UNKNOWN', b'Unknown')])),
                ('severity', models.CharField(max_length=100, choices=[(b'GREEN', b'Green'), (b'YELLOW', b'Yellow'), (b'RED', b'Red'), (b'UNKNOWN', b'Unknown')])),
                ('occurred', models.DateTimeField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('account', models.ForeignKey(related_name='alerts', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Campaign',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('campaign_id', models.BigIntegerField(unique=True)),
                ('campaign', models.CharField(help_text=b'Campaign name', max_length=255)),
                ('campaign_state', models.CharField(max_length=20, choices=[(b'enabled', b'Enabled'), (b'paused', b'Paused'), (b'removed', b'Removed')])),
                ('budget_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('budget', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Budget', null=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('account', models.ForeignKey(related_name='campaigns', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAccountMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('device', models.CharField(help_text=b'Device', max_length=255, choices=[(b'Other', b'Other'), (b'Computers', b'Computers'), (b'Mobile devices with full browsers', b'Mobile devices with full browsers'), (b'Tablets with full browsers', b'Tablets with full browsers')])),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_budget', models.DecimalField(help_text=b'Content Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_click_rate', models.DecimalField(help_text=b'Invalid click rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_clicks', models.BigIntegerField(help_text=b'Invalid clicks', null=True, blank=True)),
                ('search_lost_is_budget', models.DecimalField(help_text=b'Search Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('account', models.ForeignKey(related_name='metrics', to='django_google_adwords.Account')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAdGroupMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('bid_strategy_id', models.BigIntegerField(help_text=b'Bid Strategy ID', null=True, blank=True)),
                ('bid_strategy_name', models.CharField(max_length=255, null=True, blank=True)),
                ('bid_strategy_type', models.CharField(blank=True, max_length=40, null=True, help_text=b'Bid Strategy Type', choices=[(b'auto', b'Budget Optimizer'), (b'max/target cpa', b'Conversion Optimizer'), (b'cpc', b'Manual CPC'), (b'cpm', b'Manual CPM'), (b'Target search page location', b'Page One Promoted'), (b'max cpa percent', b'Percent CPA'), (b'Maximize clicks', b'Target Spend'), (b'Enhanced CPC', b'Enhanced CPC'), (b'Target CPA', b'Target CPA'), (b'Target ROAS', b'Target ROAS'), (b'None', b'None'), (b'unknown', b'Unknown')])),
                ('max_cpa_converted_clicks_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('max_cpa_converted_clicks', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Max. CPA (converted clicks)', null=True)),
                ('value_est_total_conv', models.DecimalField(help_text=b'Value / est. total conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('ad_group', models.ForeignKey(related_name='metrics', to='django_google_adwords.AdGroup')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyAdMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('ad', models.ForeignKey(related_name='metrics', to='django_google_adwords.Ad')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DailyCampaignMetrics',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('avg_cpc_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpc', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPC', null=True)),
                ('avg_cpm_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('avg_cpm', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Avg. CPM', null=True)),
                ('avg_position', models.DecimalField(help_text=b'Avg. position', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('clicks', models.IntegerField(help_text=b'Clicks', null=True, blank=True)),
                ('click_conversion_rate', models.DecimalField(help_text=b'Click conversion rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conv_rate', models.DecimalField(help_text=b'Conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('converted_clicks', models.BigIntegerField(help_text=b'Converted clicks', null=True, blank=True)),
                ('total_conv_value', models.DecimalField(help_text=b'Total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('conversions', models.BigIntegerField(help_text=b'Conversions', null=True, blank=True)),
                ('cost_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost', null=True)),
                ('cost_converted_click_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_converted_click', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / converted click', null=True)),
                ('cost_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / conv.', null=True)),
                ('ctr', models.DecimalField(help_text=b'CTR', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('impressions', models.BigIntegerField(help_text=b'Impressions', null=True, blank=True)),
                ('day', models.DateField(help_text=b'When this metric occurred')),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True, auto_now_add=True)),
                ('content_impr_share', models.DecimalField(help_text=b'Content Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('content_lost_is_rank', models.DecimalField(help_text=b'Content Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('cost_est_total_conv_currency', djmoney.models.fields.CurrencyField(default='XYZ', max_length=3, editable=False, choices=[(b'AUD', 'Australian Dollar')])),
                ('cost_est_total_conv', djmoney.models.fields.MoneyField(decimal_places=2, default=Decimal('0'), max_digits=12, blank=True, help_text=b'Cost / est. total conv.', null=True)),
                ('est_cross_device_conv', models.BigIntegerField(help_text=b'Est. cross-device conv.', null=True, blank=True)),
                ('est_total_conv_rate', models.DecimalField(help_text=b'Est. total conv. rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value', models.DecimalField(help_text=b'Est. total conv. value', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_click', models.DecimalField(help_text=b'Est. total conv. value / click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv_value_cost', models.DecimalField(help_text=b'Est. total conv. value / cost', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('est_total_conv', models.BigIntegerField(help_text=b'Est. total conv.', null=True, blank=True)),
                ('search_exact_match_is', models.DecimalField(help_text=b'Search Exact match IS', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_impr_share', models.DecimalField(help_text=b'Search Impr. share', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('search_lost_is_rank', models.DecimalField(help_text=b'Search Lost IS (rank)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('bid_strategy_id', models.BigIntegerField(help_text=b'Bid Strategy ID', null=True, blank=True)),
                ('bid_strategy_name', models.CharField(max_length=255, null=True, blank=True)),
                ('bid_strategy_type', models.CharField(blank=True, max_length=40, null=True, help_text=b'Bid Strategy Type', choices=[(b'auto', b'Budget Optimizer'), (b'max/target cpa', b'Conversion Optimizer'), (b'cpc', b'Manual CPC'), (b'cpm', b'Manual CPM'), (b'Target search page location', b'Page One Promoted'), (b'max cpa percent', b'Percent CPA'), (b'Maximize clicks', b'Target Spend'), (b'Enhanced CPC', b'Enhanced CPC'), (b'Target CPA', b'Target CPA'), (b'Target ROAS', b'Target ROAS'), (b'None', b'None'), (b'unknown', b'Unknown')])),
                ('content_lost_is_budget', models.DecimalField(help_text=b'Content Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_click_rate', models.DecimalField(help_text=b'Invalid click rate', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('invalid_clicks', models.BigIntegerField(help_text=b'Invalid clicks', null=True, blank=True)),
                ('search_lost_is_budget', models.DecimalField(help_text=b'Search Lost IS (budget)', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_converted_click', models.DecimalField(help_text=b'Value / converted click', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('value_conv', models.DecimalField(help_text=b'Value / conv.', null=True, max_digits=12, decimal_places=2, blank=True)),
                ('view_through_conv', models.BigIntegerField(help_text=b'View-through conv.', null=True, blank=True)),
                ('campaign', models.ForeignKey(related_name='metrics', to='django_google_adwords.Campaign')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='ReportFile',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('file', models.FileField(max_length=255, null=True, upload_to=django_google_adwords.models.reportfile_file_upload_to, blank=True)),
                ('processed', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='adgroup',
            name='campaign',
            field=models.ForeignKey(related_name='ad_groups', to='django_google_adwords.Campaign'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='ad',
            name='ad_group',
            field=models.ForeignKey(related_name='ads', to='django_google_adwords.AdGroup'),
            preserve_default=True,
        ),
    ]



from django.core.cache import cache
from django.conf import settings
from django.template.defaultfilters import slugify


def get_googleadwords_lock_id(model, identifier):
    _identifier = slugify(identifier) 
    return '%s-%s-%s' % (settings.GOOGLEADWORDS_LOCK_ID, model.__name__, _identifier)


def acquire_googleadwords_lock(model, idenitier):
    # cache.add fails if if the key already exists
    return cache.add(get_googleadwords_lock_id(model, idenitier), "true", settings.GOOGLEADWORDS_LOCK_TIMEOUT)


def release_googleadwords_lock(model, idenitier):
    # memcache delete is very slow, but we have to use it to take
    # advantage of using add() for atomic locking
    return cache.delete(get_googleadwords_lock_id(model, idenitier))



# -*- coding: utf-8 -*-
"""Django modelling and helpers for the Google Adwords API."""
# :copyright: (c) 2015 Alex Hayes and individual contributors,
#                 All rights reserved.
# :license:   MIT License, see LICENSE for more details.


from collections import namedtuple

version_info_t = namedtuple(
    'version_info_t', ('major', 'minor', 'micro', 'releaselevel', 'serial'),
)

VERSION = version_info_t(0, 6, 3, '', '')
__version__ = '{0.major}.{0.minor}.{0.micro}{0.releaselevel}'.format(VERSION)
__author__ = 'Alex Hayes'
__contact__ = 'alex@alution.com'
__homepage__ = 'http://github.com/alexhayes/django-cereal'
__docformat__ = 'restructuredtext'

# -eof meta-



from __future__ import absolute_import
from django.conf import settings
from django_google_adwords.models import Account, Alert
from celery.app import shared_task
from celery.canvas import chain


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_all():
    for account in Account.objects.considered_active():
        account.sync(sync_account=True, sync_campaign=True, sync_adgroup=True, sync_ad=True)


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_chain():
    tasks = []
    if settings.GOOGLEADWORDS_SYNC_ACCOUNT:
        tasks.append(sync_accounts.si())
    if settings.GOOGLEADWORDS_SYNC_CAMPAIGN:
        tasks.append(sync_campaigns.si())
    if settings.GOOGLEADWORDS_SYNC_ADGROUP:
        tasks.append(sync_adgroups.si())
    if settings.GOOGLEADWORDS_SYNC_AD:
        tasks.append(sync_ads.si())

    chain(*tasks).apply_async()


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_accounts():
    for account in Account.objects.considered_active():
        account.sync(sync_account=True, sync_campaign=False, sync_adgroup=False, sync_ad=False)


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_campaigns():
    for account in Account.objects.considered_active():
        account.sync(sync_account=False, sync_campaign=True, sync_adgroup=False, sync_ad=False)


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_adgroups():
    for account in Account.objects.considered_active():
        account.sync(sync_account=False, sync_campaign=False, sync_adgroup=True, sync_ad=False)


@shared_task(queue=settings.GOOGLEADWORDS_HOUSEKEEPING_CELERY_QUEUE)
def sync_ads():
    for account in Account.objects.considered_active():
        account.sync(sync_account=False, sync_campaign=False, sync_adgroup=False, sync_ad=True)



from __future__ import absolute_import

from datetime import date
from decimal import Decimal
import os

from django_google_adwords.models import ReportFile, Account, Campaign, AdGroup, \
    DailyAccountMetrics, DailyCampaignMetrics, DailyAdGroupMetrics, Ad, \
    DailyAdMetrics
from django.test.testcases import TestCase, TransactionTestCase


def _get_test_media_file_path(name):
    return os.path.join(os.path.dirname(os.path.realpath(__file__)), 'media', name)


def _get_report_file(name):
    report_file = ReportFile.objects.create()  #: :type report_file: ReportFile
    report_file.save_path(_get_test_media_file_path(name))
    return report_file


class DjangoGoogleAdwordsTestCase(TransactionTestCase):
    fixtures = [
        'django_google_adwords.yaml'
    ]
    
    def test_account_update_from_initial(self):
        report_file = _get_report_file('account_report.gz')

        # Check that initial values are Null
        account = Account.objects.get(pk=1)
        self.assertEqual(account.account, None)
        self.assertEqual(account.currency, None)
        self.assertEqual(account.account_last_synced, None)

        # Run the Account report populate
        account.start_sync()
        account.sync_account(report_file=report_file)
        account.finish_account_sync()
        account.finish_sync()

        # Check that the Account fields have been updated
        account = Account.objects.get(pk=1)
        self.assertEqual(account.account, 'example.com.au')
        self.assertEqual(account.currency, 'AUD')
        self.assertIsInstance(account.account_last_synced, date)

    def test_campaign_create(self):
        report_file = _get_report_file('campaign_report.gz')

        # Run the Campaign report populate
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_campaign_sync()
        account.finish_sync()

        # Check that the Campaigns have been populated
        account = Account.objects.get(pk=1)
        campaigns = account.campaigns.all()
        self.assertEqual(campaigns.count(), 5)

        # Check campaign attributes populated correctly
        c1 = Campaign.objects.get(campaign_id=7679201)
        self.assertEqual(c1.account, account)
        self.assertEqual(c1.campaign, 'Campaign #1')
        self.assertEqual(c1.campaign_state, Campaign.STATE_PAUSED)
        self.assertEqual(c1.budget.amount, Decimal('10.0'))

        c2 = Campaign.objects.get(campaign_id=7679441)
        self.assertEqual(c2.account, account)
        self.assertEqual(c2.campaign, 'Campaign #2')
        self.assertEqual(c2.campaign_state, Campaign.STATE_PAUSED)
        self.assertEqual(c2.budget.amount, Decimal('3.0'))

        c3 = Campaign.objects.get(campaign_id=7679621)
        self.assertEqual(c3.account, account)
        self.assertEqual(c3.campaign, 'Campaign #3')
        self.assertEqual(c3.campaign_state, Campaign.STATE_PAUSED)
        self.assertEqual(c3.budget.amount, Decimal('4.0'))

        c4 = Campaign.objects.get(campaign_id=7756901)
        self.assertEqual(c4.account, account)
        self.assertEqual(c4.campaign, 'Campaign #4')
        self.assertEqual(c4.campaign_state, Campaign.STATE_REMOVED)
        self.assertEqual(c4.budget.amount, Decimal('15.0'))

        c5 = Campaign.objects.get(campaign_id=7783061)
        self.assertEqual(c5.account, account)
        self.assertEqual(c5.campaign, 'Campaign #5')
        self.assertEqual(c5.campaign_state, Campaign.STATE_PAUSED)
        self.assertEqual(c5.budget.amount, Decimal('8.0'))

    def test_campaign_update(self):
        # Run the Campaign report populate
        report_file = _get_report_file('campaign_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_campaign_sync()
        account.finish_sync()

        # Check campaign attributes populated correctly
        c = Campaign.objects.get(campaign_id=7679201)
        self.assertEqual(c.campaign, 'Campaign #1')
        self.assertEqual(c.campaign_state, Campaign.STATE_PAUSED)
        self.assertEqual(c.budget.amount, Decimal('10.0'))

        # Run the updated Campaign report populate
        report_file = _get_report_file('campaign_report_update.gz')
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_account_sync()
        account.finish_sync()

        # Check campaign attributes updated correctly
        uc = Campaign.objects.get(campaign_id=7679201)
        self.assertEqual(uc.campaign, 'Campaign #1')
        self.assertEqual(uc.campaign_state, Campaign.STATE_ENABLED)
        self.assertEqual(uc.budget.amount, Decimal('100.0'))

    def test_ad_group_create(self):
        report_file = _get_report_file('adgroup_report.gz')

        # Run the Ad Group report populate
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Check that the Ad Groups have been populated
        account = Account.objects.get(pk=1)
        ad_groups = AdGroup.objects.filter(campaign__account=account)
        self.assertEqual(ad_groups.count(), 5)

        # Check Ad Group attributes populated correctly
        ad_group = AdGroup.objects.get(ad_group_id=323809001)
        self.assertEqual(ad_group.campaign.campaign_id, 7679201)
        self.assertEqual(ad_group.ad_group, 'AdGroup #1')
        self.assertEqual(ad_group.ad_group_state, AdGroup.STATE_PAUSED)

    def test_ad_group_update(self):
        # Run the Ad Group report populate
        report_file = _get_report_file('adgroup_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Run the Ad Group report populate to update rows
        report_file = _get_report_file('adgroup_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Check Ad Group attributes updated correctly
        ad_group = AdGroup.objects.get(ad_group_id=323809001)
        self.assertEqual(ad_group.campaign.campaign_id, 7679201)
        self.assertEqual(ad_group.ad_group, 'AdGroup #1')
        self.assertEqual(ad_group.ad_group_state, AdGroup.STATE_ENABLED)

    def test_ad_create(self):
        # Run the Ad report populate
        report_file = _get_report_file('ad_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Check that the Ads have been populated
        account = Account.objects.get(pk=1)
        ads = Ad.objects.filter(ad_group__campaign__account=account)
        self.assertEqual(ads.count(), 44)

        # Check Ad attributes populated correctly
        ad = Ad.objects.get(ad_id=40564055441)
        self.assertEqual(ad.ad_state, Ad.STATE_ENABLED)
        self.assertEqual(ad.ad_type, Ad.TYPE_TEXT_AD)
        self.assertEqual(ad.destination_url, 'http://example.net.au/Home.php')
        self.assertEqual(ad.display_url, 'example.net.au')
        self.assertEqual(ad.ad, 'Doncaster Real Estate')

        self.assertEqual(ad.description_line_1, 'Trusted by Victorian Home Owners.')
        self.assertEqual(ad.description_line_2, '90 Years Exp Request Free Appraisal')

    def test_ad_update(self):
        # Run the Ad report populate
        report_file = _get_report_file('ad_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Run the Ad report populate update
        report_file = _get_report_file('ad_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Check that the Ads have been updated and there are still only 9
        account = Account.objects.get(pk=1)
        ads = Ad.objects.filter(ad_group__campaign__account=account)
        self.assertEqual(ads.count(), 44)

        # Check Ad attributes updated correctly
        ad = Ad.objects.get(ad_id=40564055441)
        self.assertEqual(ad.ad_state, Ad.STATE_ENABLED)
        self.assertEqual(ad.ad_type, Ad.TYPE_TEXT_AD)
        self.assertEqual(ad.destination_url, 'http://example.net.au/Home2.php')
        self.assertEqual(ad.display_url, 'example.net.au/test')
        self.assertEqual(ad.ad, 'Doncaster Real Estate')
        self.assertEqual(ad.description_line_1, 'Trusted by Victorian Home Owners. FTW')
        self.assertEqual(ad.description_line_2, '90 Years Exp Request Free Appraisal FTW')

    def test_daily_account_metrics_create(self):
        report_file = _get_report_file('account_report.gz')

        # Run the Account report populate
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_account(report_file=report_file)
        account.finish_account_sync()
        account.finish_sync()

        # Check that the Daily Account Metrics have been populated
        account_metrics = DailyAccountMetrics.objects.filter(account=account)
        self.assertEqual(account_metrics.count(), 30)

        # Check the fields of one of them
        account_metric = DailyAccountMetrics.objects.get(account=account, device=DailyAccountMetrics.DEVICE_DESKTOP, day=date(2014, 7, 28))
        self.assertEqual(account_metric.avg_cpc.amount, Decimal('1.91'))
        self.assertEqual(account_metric.avg_cpm.amount, Decimal('1.85'))
        self.assertEqual(account_metric.avg_position, Decimal('1.0'))
        self.assertEqual(account_metric.clicks, 5)
        self.assertEqual(account_metric.content_lost_is_budget, Decimal('23.39'))
        self.assertEqual(account_metric.content_impr_share, Decimal('10.00'))
        self.assertEqual(account_metric.content_lost_is_rank, Decimal('73.41'))
        self.assertEqual(account_metric.click_conversion_rate, Decimal('0.0'))
        self.assertEqual(account_metric.conv_rate, Decimal('0.0'))
        self.assertEqual(account_metric.converted_clicks, 0)
        self.assertEqual(account_metric.conversions, 0)
        self.assertEqual(account_metric.cost.amount, Decimal('9.57'))
        self.assertEqual(account_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(account_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(account_metric.cost_est_total_conv.amount, Decimal('0.00'))
        self.assertEqual(account_metric.ctr, Decimal('0.10'))
        self.assertEqual(account_metric.est_cross_device_conv, None)
        self.assertEqual(account_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value_click, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value_cost, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv, 0)
        self.assertEqual(account_metric.impressions, 5183)
        self.assertEqual(account_metric.invalid_click_rate, Decimal('0.00'))
        self.assertEqual(account_metric.invalid_clicks, 0)
        self.assertEqual(account_metric.search_lost_is_budget, Decimal('23.81'))
        self.assertEqual(account_metric.search_exact_match_is, Decimal('76.19'))
        self.assertEqual(account_metric.search_impr_share, Decimal('76.19'))
        self.assertEqual(account_metric.search_lost_is_rank, Decimal('0.00'))

    def test_daily_account_metrics_update(self):
        # Run the Account report populate
        report_file = _get_report_file('account_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_account(report_file=report_file)
        account.finish_account_sync()
        account.finish_sync()

        # Run the Account report populate with data to update
        report_file = _get_report_file('account_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_account(report_file=report_file)
        account.finish_account_sync()
        account.finish_sync()

        # Check that the Daily Account Metrics have been populated
        account_metrics = DailyAccountMetrics.objects.filter(account=account)
        self.assertEqual(account_metrics.count(), 30)

        # Check the fields of one of them to ensure the update occurred correctly
        account_metric = DailyAccountMetrics.objects.get(account=account, device=DailyAccountMetrics.DEVICE_DESKTOP, day=date(2014, 7, 28))
        self.assertEqual(account_metric.avg_cpc.amount, Decimal('1.81'))
        self.assertEqual(account_metric.avg_cpm.amount, Decimal('1.85'))
        self.assertEqual(account_metric.avg_position, Decimal('1.0'))
        self.assertEqual(account_metric.clicks, 5)
        self.assertEqual(account_metric.content_lost_is_budget, Decimal('23.39'))
        self.assertEqual(account_metric.content_impr_share, Decimal('10.00'))
        self.assertEqual(account_metric.content_lost_is_rank, Decimal('75.41'))
        self.assertEqual(account_metric.click_conversion_rate, Decimal('0.0'))
        self.assertEqual(account_metric.conv_rate, Decimal('0.0'))
        self.assertEqual(account_metric.converted_clicks, 0)
        self.assertEqual(account_metric.conversions, 0)
        self.assertEqual(account_metric.cost.amount, Decimal('9.57'))
        self.assertEqual(account_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(account_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(account_metric.cost_est_total_conv.amount, Decimal('0.00'))
        self.assertEqual(account_metric.ctr, Decimal('0.10'))
        self.assertEqual(account_metric.est_cross_device_conv, None)
        self.assertEqual(account_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value_click, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv_value_cost, Decimal('0.00'))
        self.assertEqual(account_metric.est_total_conv, 0)
        self.assertEqual(account_metric.impressions, 5183)
        self.assertEqual(account_metric.invalid_click_rate, Decimal('0.00'))
        self.assertEqual(account_metric.invalid_clicks, 0)
        self.assertEqual(account_metric.search_lost_is_budget, Decimal('23.81'))
        self.assertEqual(account_metric.search_exact_match_is, Decimal('76.19'))
        self.assertEqual(account_metric.search_impr_share, Decimal('76.19'))
        self.assertEqual(account_metric.search_lost_is_rank, Decimal('10.00'))

    def test_daily_campaign_metrics_create(self):
        # Run the Campaign report populate
        report_file = _get_report_file('campaign_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_campaign_sync()
        account.finish_sync()

        # Check campaign metrics were created
        campaign_metrics = DailyCampaignMetrics.objects.filter(campaign__account=account)
        self.assertEqual(campaign_metrics.count(), 15)

        # Check a row to ensure fields are correct
        campaign_metric = DailyCampaignMetrics.objects.get(campaign__campaign_id=7679201, day=date(2014, 8, 4))
        self.assertEqual(campaign_metric.avg_cpc.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.avg_cpm.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.avg_position, Decimal('0.00'))
        self.assertEqual(campaign_metric.bid_strategy_id, 0)
        self.assertEqual(campaign_metric.bid_strategy_name, '')
        self.assertEqual(campaign_metric.bid_strategy_type, 'cpc')
        self.assertEqual(campaign_metric.clicks, 0)
        self.assertEqual(campaign_metric.content_lost_is_budget, None)
        self.assertEqual(campaign_metric.content_impr_share, None)
        self.assertEqual(campaign_metric.content_lost_is_rank, None)
        self.assertEqual(campaign_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.converted_clicks, 0)
        self.assertEqual(campaign_metric.conversions, 0)
        self.assertEqual(campaign_metric.cost.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_est_total_conv.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.ctr, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_cross_device_conv, None)
        self.assertEqual(campaign_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv, 0)
        self.assertEqual(campaign_metric.est_total_conv_value, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv_value_click, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv_value_cost, Decimal('0.00'))
        self.assertEqual(campaign_metric.impressions, 0)
        self.assertEqual(campaign_metric.invalid_click_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.invalid_clicks, 0)
        self.assertEqual(campaign_metric.search_lost_is_budget, None)
        self.assertEqual(campaign_metric.search_exact_match_is, None)
        self.assertEqual(campaign_metric.search_impr_share, None)
        self.assertEqual(campaign_metric.search_lost_is_rank, None)

    def test_daily_campaign_metrics_update(self):
        # Run the Campaign report populate
        report_file = _get_report_file('campaign_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_campaign_sync()
        account.finish_sync()

        # Run the Campaign report populate to update rows
        report_file = _get_report_file('campaign_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_campaign(report_file=report_file)
        account.finish_campaign_sync()
        account.finish_sync()

        campaign_metrics = DailyCampaignMetrics.objects.filter(campaign__account=account)
        self.assertEqual(campaign_metrics.count(), 15)

        # Check a row to ensure fields are correct
        campaign_metric = DailyCampaignMetrics.objects.get(campaign__campaign_id=7679201, day=date(2014, 8, 4))
        self.assertEqual(campaign_metric.avg_cpc.amount, Decimal('1.00'))
        self.assertEqual(campaign_metric.avg_cpm.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.avg_position, Decimal('0.00'))
        self.assertEqual(campaign_metric.bid_strategy_id, 0)
        self.assertEqual(campaign_metric.bid_strategy_name, '')
        self.assertEqual(campaign_metric.bid_strategy_type, 'cpc')
        self.assertEqual(campaign_metric.clicks, 0)
        self.assertEqual(campaign_metric.content_lost_is_budget, None)
        self.assertEqual(campaign_metric.content_impr_share, None)
        self.assertEqual(campaign_metric.content_lost_is_rank, None)
        self.assertEqual(campaign_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.converted_clicks, 0)
        self.assertEqual(campaign_metric.conversions, 0)
        self.assertEqual(campaign_metric.cost.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.cost_est_total_conv.amount, Decimal('0.00'))
        self.assertEqual(campaign_metric.ctr, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_cross_device_conv, None)
        self.assertEqual(campaign_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv, 0)
        self.assertEqual(campaign_metric.est_total_conv_value, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv_value_click, Decimal('0.00'))
        self.assertEqual(campaign_metric.est_total_conv_value_cost, Decimal('0.00'))
        self.assertEqual(campaign_metric.impressions, 50)
        self.assertEqual(campaign_metric.invalid_click_rate, Decimal('0.00'))
        self.assertEqual(campaign_metric.invalid_clicks, 0)
        self.assertEqual(campaign_metric.search_lost_is_budget, None)
        self.assertEqual(campaign_metric.search_exact_match_is, None)
        self.assertEqual(campaign_metric.search_impr_share, None)
        self.assertEqual(campaign_metric.search_lost_is_rank, None)

    def test_daily_ad_group_metrics_create(self):
        # Run the Ad Group report populate
        report_file = _get_report_file('adgroup_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Check Ad Group metrics were created
        ad_group_metrics = DailyAdGroupMetrics.objects.filter(ad_group__campaign__account=account)
        self.assertEqual(ad_group_metrics.count(), 50)

        # Check a row to ensure fields are correct
        ad_group_metric = DailyAdGroupMetrics.objects.get(ad_group__ad_group_id=323809001, day=date(2014, 7, 28))

        self.assertEqual(ad_group_metric.max_cpa_converted_clicks, None)
        self.assertEqual(ad_group_metric.value_est_total_conv, Decimal('0.0'))
        self.assertEqual(ad_group_metric.bid_strategy_id, 0)
        self.assertEqual(ad_group_metric.bid_strategy_name, '')
        self.assertEqual(ad_group_metric.bid_strategy_type, DailyAdGroupMetrics.BID_STRATEGY_TYPE_MANUAL_CPC)
        self.assertEqual(ad_group_metric.content_impr_share, None)
        self.assertEqual(ad_group_metric.content_lost_is_rank, None)
        self.assertEqual(ad_group_metric.cost_est_total_conv.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.est_cross_device_conv, None)
        self.assertEqual(ad_group_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.est_total_conv_value, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv_value_click, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv_value_cost, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv, 0)
        self.assertEqual(ad_group_metric.search_exact_match_is, None)
        self.assertEqual(ad_group_metric.search_impr_share, None)
        self.assertEqual(ad_group_metric.search_lost_is_rank, None)
        self.assertEqual(ad_group_metric.value_converted_click, Decimal('0.0'))
        self.assertEqual(ad_group_metric.value_conv, Decimal('0.0'))
        self.assertEqual(ad_group_metric.view_through_conv, None)
        self.assertEqual(ad_group_metric.avg_cpc.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.avg_cpm.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.avg_position, Decimal('0.0'))
        self.assertEqual(ad_group_metric.clicks, 0)
        self.assertEqual(ad_group_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.converted_clicks, 0)
        self.assertEqual(ad_group_metric.conversions, 0)
        self.assertEqual(ad_group_metric.cost.amount, Decimal('0.0'))
        self.assertEqual(ad_group_metric.cost_converted_click.amount, Decimal('0.0'))
        self.assertEqual(ad_group_metric.cost_conv.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.ctr, Decimal('0.00'))
        self.assertEqual(ad_group_metric.impressions, 0)

    def test_daily_ad_group_metrics_update(self):
        # Run the Ad Group report populate
        report_file = _get_report_file('adgroup_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Run the Ad Group report populate update
        report_file = _get_report_file('adgroup_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad_group(report_file=report_file)
        account.finish_ad_group_sync()
        account.finish_sync()

        # Check Ad Group metrics were created
        ad_group_metrics = DailyAdGroupMetrics.objects.filter(ad_group__campaign__account=account)
        self.assertEqual(ad_group_metrics.count(), 50)

        # Check a row to ensure fields are correct
        ad_group_metric = DailyAdGroupMetrics.objects.get(ad_group__ad_group_id=323809001, day=date(2014, 7, 28))

        self.assertEqual(ad_group_metric.max_cpa_converted_clicks, None)
        self.assertEqual(ad_group_metric.value_est_total_conv, Decimal('0.0'))
        self.assertEqual(ad_group_metric.bid_strategy_id, 0)
        self.assertEqual(ad_group_metric.bid_strategy_name, '')
        self.assertEqual(ad_group_metric.bid_strategy_type, DailyAdGroupMetrics.BID_STRATEGY_TYPE_MANUAL_CPC)
        self.assertEqual(ad_group_metric.content_impr_share, None)
        self.assertEqual(ad_group_metric.content_lost_is_rank, None)
        self.assertEqual(ad_group_metric.cost_est_total_conv.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.est_cross_device_conv, None)
        self.assertEqual(ad_group_metric.est_total_conv_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.est_total_conv_value, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv_value_click, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv_value_cost, Decimal('0.0'))
        self.assertEqual(ad_group_metric.est_total_conv, 0)
        self.assertEqual(ad_group_metric.search_exact_match_is, None)
        self.assertEqual(ad_group_metric.search_impr_share, None)
        self.assertEqual(ad_group_metric.search_lost_is_rank, None)
        self.assertEqual(ad_group_metric.value_converted_click, Decimal('0.0'))
        self.assertEqual(ad_group_metric.value_conv, Decimal('0.0'))
        self.assertEqual(ad_group_metric.view_through_conv, None)
        self.assertEqual(ad_group_metric.avg_cpc.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.avg_cpm.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.avg_position, Decimal('0.0'))
        self.assertEqual(ad_group_metric.clicks, 0)
        self.assertEqual(ad_group_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(ad_group_metric.converted_clicks, 0)
        self.assertEqual(ad_group_metric.conversions, 0)
        self.assertEqual(ad_group_metric.cost.amount, Decimal('0.0'))
        self.assertEqual(ad_group_metric.cost_converted_click.amount, Decimal('0.0'))
        self.assertEqual(ad_group_metric.cost_conv.amount, Decimal('0'))
        self.assertEqual(ad_group_metric.ctr, Decimal('0.00'))
        self.assertEqual(ad_group_metric.impressions, 100)

    def test_daily_ad_metrics_create(self):
        # Run the Ad report populate
        report_file = _get_report_file('ad_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Check Ad Group metrics were created
        ad_metrics = DailyAdMetrics.objects.filter(ad__ad_group__campaign__account=account)
        self.assertEqual(ad_metrics.count(), 44)

        # Check a row to ensure fields are correct
        ad_metric = DailyAdMetrics.objects.get(ad__ad_id=40564055441, day=date(2014, 8, 6))

        self.assertEqual(ad_metric.avg_cpc.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.avg_cpm.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.avg_position, Decimal('1.2'))
        self.assertEqual(ad_metric.clicks, 0)
        self.assertEqual(ad_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(ad_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(ad_metric.converted_clicks, 0)
        self.assertEqual(ad_metric.conversions, 0)
        self.assertEqual(ad_metric.cost.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.ctr, Decimal('0.00'))
        self.assertEqual(ad_metric.impressions, 20)
        self.assertEqual(ad_metric.value_converted_click, Decimal('0.00'))
        self.assertEqual(ad_metric.value_conv, Decimal('0.0'))
        self.assertEqual(ad_metric.view_through_conv, None)

    def test_daily_ad_metrics_update(self):
        # Run the Ad report populate
        report_file = _get_report_file('ad_report.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Run the Ad report update
        report_file = _get_report_file('ad_report_update.gz')
        account = Account.objects.get(pk=1)
        account.start_sync()
        account.sync_ad(report_file=report_file)
        account.finish_ad_sync()
        account.finish_sync()

        # Check Ad Group metrics were created and not duplicated
        ad_metrics = DailyAdMetrics.objects.filter(ad__ad_group__campaign__account=account)
        self.assertEqual(ad_metrics.count(), 44)

        # Check a row to ensure fields are correct
        ad_metric = DailyAdMetrics.objects.get(ad__ad_id=40564055441, day=date(2014, 8, 6))

        self.assertEqual(ad_metric.avg_cpc.amount, Decimal('1.00'))
        self.assertEqual(ad_metric.avg_cpm.amount, Decimal('1.00'))
        self.assertEqual(ad_metric.avg_position, Decimal('1.3'))
        self.assertEqual(ad_metric.clicks, 0)
        self.assertEqual(ad_metric.click_conversion_rate, Decimal('0.00'))
        self.assertEqual(ad_metric.conv_rate, Decimal('0.00'))
        self.assertEqual(ad_metric.converted_clicks, 0)
        self.assertEqual(ad_metric.conversions, 0)
        self.assertEqual(ad_metric.cost.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.cost_converted_click.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.cost_conv.amount, Decimal('0.00'))
        self.assertEqual(ad_metric.ctr, Decimal('0.00'))
        self.assertEqual(ad_metric.impressions, 30)
        self.assertEqual(ad_metric.value_converted_click, Decimal('0.00'))
        self.assertEqual(ad_metric.value_conv, Decimal('0.0'))
        self.assertEqual(ad_metric.view_through_conv, None)



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Deleting field 'Ad.description_line1'
        db.delete_column(u'django_google_adwords_ad', 'description_line1')

        # Deleting field 'Ad.description_line2'
        db.delete_column(u'django_google_adwords_ad', 'description_line2')

        # Adding field 'Ad.description_line_1'
        db.add_column(u'django_google_adwords_ad', 'description_line_1',
                      self.gf('django.db.models.fields.TextField')(null=True, blank=True),
                      keep_default=False)

        # Adding field 'Ad.description_line_2'
        db.add_column(u'django_google_adwords_ad', 'description_line_2',
                      self.gf('django.db.models.fields.TextField')(null=True, blank=True),
                      keep_default=False)


    def backwards(self, orm):
        # Adding field 'Ad.description_line1'
        db.add_column(u'django_google_adwords_ad', 'description_line1',
                      self.gf('django.db.models.fields.TextField')(null=True, blank=True),
                      keep_default=False)

        # Adding field 'Ad.description_line2'
        db.add_column(u'django_google_adwords_ad', 'description_line2',
                      self.gf('django.db.models.fields.TextField')(null=True, blank=True),
                      keep_default=False)

        # Deleting field 'Ad.description_line_1'
        db.delete_column(u'django_google_adwords_ad', 'description_line_1')

        # Deleting field 'Ad.description_line_2'
        db.delete_column(u'django_google_adwords_ad', 'description_line_2')


    models = {
        u'django_google_adwords.account': {
            'Meta': {'object_name': 'Account'},
            'account': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'account_id': ('django.db.models.fields.BigIntegerField', [], {'unique': 'True'}),
            'account_last_synced': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'ad_group_last_synced': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'ad_last_synced': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'campaign_last_synced': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'currency': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'status': ('django.db.models.fields.CharField', [], {'default': "'active'", 'max_length': '32'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.ad': {
            'Meta': {'object_name': 'Ad'},
            'ad': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'ad_group': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'ads'", 'to': u"orm['django_google_adwords.AdGroup']"}),
            'ad_id': ('django.db.models.fields.BigIntegerField', [], {}),
            'ad_state': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'ad_type': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description_line_1': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'description_line_2': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'destination_url': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'display_url': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.adgroup': {
            'Meta': {'object_name': 'AdGroup'},
            'ad_group': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'ad_group_id': ('django.db.models.fields.BigIntegerField', [], {'unique': 'True'}),
            'ad_group_state': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'campaign': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'ad_groups'", 'to': u"orm['django_google_adwords.Campaign']"}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.alert': {
            'Meta': {'object_name': 'Alert'},
            'account': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'alerts'", 'to': u"orm['django_google_adwords.Account']"}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'occurred': ('django.db.models.fields.DateTimeField', [], {}),
            'severity': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.campaign': {
            'Meta': {'object_name': 'Campaign'},
            'account': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'campaigns'", 'to': u"orm['django_google_adwords.Account']"}),
            'budget': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'budget_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'campaign': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'campaign_id': ('django.db.models.fields.BigIntegerField', [], {'unique': 'True'}),
            'campaign_state': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.dailyaccountmetrics': {
            'Meta': {'object_name': 'DailyAccountMetrics'},
            'account': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'metrics'", 'to': u"orm['django_google_adwords.Account']"}),
            'avg_cpc': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpc_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_cpm': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpm_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_position': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'click_conversion_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'clicks': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'content_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'content_lost_is_budget': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'content_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conversions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'converted_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'cost': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_converted_click': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_converted_click_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_est_total_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_est_total_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'ctr': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'day': ('django.db.models.fields.DateField', [], {}),
            'device': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'est_cross_device_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_cost': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'impressions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'invalid_click_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'invalid_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'search_exact_match_is': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_lost_is_budget': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.dailyadgroupmetrics': {
            'Meta': {'object_name': 'DailyAdGroupMetrics'},
            'ad_group': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'metrics'", 'to': u"orm['django_google_adwords.AdGroup']"}),
            'avg_cpc': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpc_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_cpm': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpm_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_position': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'bid_strategy_id': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'bid_strategy_name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'bid_strategy_type': ('django.db.models.fields.CharField', [], {'max_length': '40', 'null': 'True', 'blank': 'True'}),
            'click_conversion_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'clicks': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'content_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'content_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conversions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'converted_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'cost': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_converted_click': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_converted_click_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_est_total_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_est_total_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'ctr': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'day': ('django.db.models.fields.DateField', [], {}),
            'est_cross_device_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_cost': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'impressions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'max_cpa_converted_clicks': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'max_cpa_converted_clicks_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'search_exact_match_is': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
            'value_conv': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'value_converted_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'value_est_total_conv': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'view_through_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.dailyadmetrics': {
            'Meta': {'object_name': 'DailyAdMetrics'},
            'ad': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'metrics'", 'to': u"orm['django_google_adwords.Ad']"}),
            'avg_cpc': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpc_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_cpm': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpm_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_position': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'click_conversion_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'clicks': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conversions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'converted_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'cost': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_converted_click': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_converted_click_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'ctr': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'day': ('django.db.models.fields.DateField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'impressions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
            'value_conv': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'value_converted_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'view_through_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.dailycampaignmetrics': {
            'Meta': {'object_name': 'DailyCampaignMetrics'},
            'avg_cpc': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpc_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_cpm': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'avg_cpm_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'avg_position': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'bid_strategy_id': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'bid_strategy_name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'bid_strategy_type': ('django.db.models.fields.CharField', [], {'max_length': '40', 'null': 'True', 'blank': 'True'}),
            'campaign': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'metrics'", 'to': u"orm['django_google_adwords.Campaign']"}),
            'click_conversion_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'clicks': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'content_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'content_lost_is_budget': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'content_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'conversions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'converted_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'cost': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_converted_click': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_converted_click_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'cost_est_total_conv': ('money.contrib.django.models.fields.MoneyField', [], {'decimal_places': '2', 'default': '0', 'no_currency_field': 'True', 'max_digits': '12', 'blank': 'True', 'null': 'True'}),
            'cost_est_total_conv_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': "'AUD'", 'max_length': '3'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'ctr': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'day': ('django.db.models.fields.DateField', [], {}),
            'est_cross_device_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'est_total_conv_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'est_total_conv_value_cost': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'impressions': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'invalid_click_rate': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'invalid_clicks': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'search_exact_match_is': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_impr_share': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_lost_is_budget': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'search_lost_is_rank': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'total_conv_value': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
            'value_conv': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'value_converted_click': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '12', 'decimal_places': '2', 'blank': 'True'}),
            'view_through_conv': ('django.db.models.fields.BigIntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        u'django_google_adwords.reportfile': {
            'Meta': {'object_name': 'ReportFile'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'processed': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        }
    }

    complete_apps = ['django_google_adwords']